@@ -42,9 +42,7 @@ struct _GsmFailWhaleDialogPrivate
         gboolean debug_mode;
         gboolean allow_logout;
         GdkRectangle geometry;
-        gboolean show_extensions;
         GsmShellExtensions *extensions;
-        GtkWidget *extensions_box;
 };
 
 G_DEFINE_TYPE (GsmFailWhaleDialog, gsm_fail_whale_dialog, GTK_TYPE_WINDOW);
@@ -179,18 +177,11 @@ gsm_fail_whale_dialog_size_request (GtkWidget      *widget,
                                     GtkRequisition *requisition)
 {
         GsmFailWhaleDialog *fail_dialog;
-        GtkBin        *bin;
         GdkRectangle   old_geometry;
         int            position_changed = FALSE;
         int            size_changed = FALSE;
 
         fail_dialog = GSM_FAIL_WHALE_DIALOG (widget);
-        bin = GTK_BIN (widget);
-
-        if (gtk_bin_get_child (bin) &&
-            gtk_widget_get_visible (gtk_bin_get_child (bin))) {
-                gtk_widget_size_request (gtk_bin_get_child (bin), requisition);
-        }
 
         old_geometry = fail_dialog->priv->geometry;
 
@@ -275,61 +266,6 @@ on_logout_clicked (GtkWidget          *button,
         }
 }
 
-static void
-on_extension_switched (GObject            *object,
-                       GParamSpec         *spec,
-                       GsmFailWhaleDialog *fail_dialog)
-{
-        gchar *uuid;
-        gboolean enabled;
-
-        uuid = g_object_get_data (object, "uuid");
-        g_object_get (object, "active", &enabled, NULL);
-
-        gsm_shell_extensions_set_enabled (fail_dialog->priv->extensions,
-                                          uuid,
-                                          enabled);
-}
-
-static void
-build_extension_toggle (GsmShellExtensions *extensions,
-                        GsmShellExtension  *extension,
-                        gpointer            data)
-{
-        GsmFailWhaleDialog *fail_dialog = GSM_FAIL_WHALE_DIALOG (data);
-        GtkWidget *hbox;
-        GtkWidget *label;
-        GtkWidget *sw;
-
-        hbox = gtk_hbox_new (FALSE, 0);
-        gtk_widget_set_size_request (hbox, 600, -1);
-        gtk_widget_set_halign (hbox, GTK_ALIGN_CENTER);
-        gtk_widget_show (hbox);
-        gtk_box_pack_start (GTK_BOX (fail_dialog->priv->extensions_box),
-                            hbox, FALSE, FALSE, 0);
-
-        label = gtk_label_new (gsm_shell_extension_get_name (extension));
-
-        gtk_widget_show (label);
-        gtk_widget_set_halign (label, GTK_ALIGN_START);
-        gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-        sw = gtk_switch_new ();
-        gtk_switch_set_active (GTK_SWITCH (sw),
-                               gsm_shell_extension_get_is_enabled (extension));
-
-        g_object_set_data (G_OBJECT (sw),
-                           "uuid",
-                           gsm_shell_extension_get_uuid (extension));
-        g_signal_connect (G_OBJECT (sw),
-                          "notify::active",
-                          G_CALLBACK (on_extension_switched),
-                          fail_dialog);
-        gtk_widget_set_halign (label, GTK_ALIGN_END);
-        gtk_widget_show (sw);
-        gtk_box_pack_end (GTK_BOX (hbox), sw, FALSE, FALSE, 0);
-}
-
 static void
 setup_window (GsmFailWhaleDialog *fail_dialog)
 {
@@ -341,8 +277,6 @@ setup_window (GsmFailWhaleDialog *fail_dialog)
         GtkWidget *message_label;
         GtkWidget *button_box;
         GtkWidget *button;
-        GtkWidget *extensions_scroll;
-        GtkWidget *extensions_vbox;
         char *markup;
 
         priv = fail_dialog->priv;
@@ -364,7 +298,7 @@ setup_window (GsmFailWhaleDialog *fail_dialog)
         gtk_container_add (GTK_CONTAINER (fail_dialog), alignment);
         g_object_set (alignment, "valign", GTK_ALIGN_CENTER, NULL);
 
-        box = gtk_vbox_new (FALSE, 10);
+        box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
         gtk_widget_show (box);
         gtk_container_add (GTK_CONTAINER (alignment), box);
 
@@ -382,8 +316,8 @@ setup_window (GsmFailWhaleDialog *fail_dialog)
 
         if (!priv->allow_logout)
                 message_label = gtk_label_new (_("A problem has occurred and the system can't recover. Please contact a system administrator"));
-        else if (priv->show_extensions && gsm_shell_extensions_n_extensions (priv->extensions) > 0)
-                message_label = gtk_label_new (_("A problem has occurred and the system can't recover. Some of the extensions below may have caused this.\nPlease try disabling some of these, and then log out and try again."));
+        else if (priv->extensions != NULL && gsm_shell_extensions_n_extensions (priv->extensions) > 0)
+                message_label = gtk_label_new (_("A problem has occurred and the system can't recover. All extensions have been disabled as a precaution."));
         else
                 message_label = gtk_label_new (_("A problem has occurred and the system can't recover.\nPlease log out and try again."));
 
@@ -393,26 +327,7 @@ setup_window (GsmFailWhaleDialog *fail_dialog)
         gtk_box_pack_start (GTK_BOX (box),
                             message_label, FALSE, FALSE, 0);
 
-        if (priv->allow_logout && priv->show_extensions) {
-                extensions_vbox = gtk_vbox_new (TRUE, 6);
-                gtk_widget_show (extensions_vbox);
-                fail_dialog->priv->extensions_box = extensions_vbox;
-
-                extensions_scroll = gtk_scrolled_window_new (NULL, NULL);
-                gtk_widget_show (extensions_scroll);
-
-                gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (extensions_scroll),
-                                                       extensions_vbox);
-
-                gtk_box_pack_start (GTK_BOX (box),
-                                    extensions_scroll, FALSE, FALSE, 0);
-
-                gsm_shell_extensions_foreach (priv->extensions,
-                                              build_extension_toggle,
-                                              (gpointer) fail_dialog);
-        }
-
-        button_box = gtk_hbutton_box_new ();
+        button_box = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
         gtk_container_set_border_width (GTK_CONTAINER (button_box), 20);
         gtk_widget_show (button_box);
         gtk_box_pack_end (GTK_BOX (box),
@@ -432,13 +347,12 @@ static void
 gsm_fail_whale_dialog_init (GsmFailWhaleDialog *fail_dialog)
 {
         fail_dialog->priv = GSM_FAIL_WHALE_DIALOG_GET_PRIVATE (fail_dialog);
-        fail_dialog->priv->extensions = g_object_new (GSM_TYPE_SHELL_EXTENSIONS, NULL);
 }
 
 void
-gsm_fail_whale_dialog_we_failed (gboolean debug_mode,
-                                 gboolean allow_logout,
-                                 gboolean show_extensions)
+gsm_fail_whale_dialog_we_failed (gboolean            debug_mode,
+                                 gboolean            allow_logout,
+                                 GsmShellExtensions *extensions)
 
 {
         static GsmFailWhaleDialog *current_dialog = NULL;
@@ -451,7 +365,8 @@ gsm_fail_whale_dialog_we_failed (gboolean debug_mode,
         fail_dialog = g_object_new (GSM_TYPE_FAIL_WHALE_DIALOG, NULL);
         fail_dialog->priv->debug_mode = debug_mode;
         fail_dialog->priv->allow_logout = allow_logout;
-        fail_dialog->priv->show_extensions = show_extensions;
+        fail_dialog->priv->extensions = extensions;
+
         setup_window (fail_dialog);
 
         current_dialog = fail_dialog;
